==> qt6-virtualkeyboard-6.1.0-1-aarch64.pkg.tar.xz: usr/lib/cmake/Qt6VirtualKeyboard/Qt6QtVirtualKeyboardOpenWnnPluginAdditionalTargetInfo.cmake <==
# Additional target information for Qt6QtVirtualKeyboardOpenWnnPlugin
if(NOT DEFINED QT_DEFAULT_IMPORT_CONFIGURATION)
    set(QT_DEFAULT_IMPORT_CONFIGURATION RELEASE)
endif()
get_target_property(_qt_imported_location Qt6::QtVirtualKeyboardOpenWnnPlugin IMPORTED_LOCATION_RELEASE)
get_target_property(_qt_imported_implib Qt6::QtVirtualKeyboardOpenWnnPlugin IMPORTED_IMPLIB_RELEASE)
get_target_property(_qt_imported_soname Qt6::QtVirtualKeyboardOpenWnnPlugin IMPORTED_SONAME_RELEASE)
get_target_property(_qt_imported_location_default Qt6::QtVirtualKeyboardOpenWnnPlugin IMPORTED_LOCATION_${QT_DEFAULT_IMPORT_CONFIGURATION})
get_target_property(_qt_imported_implib_default Qt6::QtVirtualKeyboardOpenWnnPlugin IMPORTED_IMPLIB_${QT_DEFAULT_IMPORT_CONFIGURATION})
get_target_property(_qt_imported_soname_default Qt6::QtVirtualKeyboardOpenWnnPlugin IMPORTED_SONAME_${QT_DEFAULT_IMPORT_CONFIGURATION})

# Import target "Qt6::QtVirtualKeyboardOpenWnnPlugin" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::QtVirtualKeyboardOpenWnnPlugin APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)

if(_qt_imported_location)
    set_property(TARGET Qt6::QtVirtualKeyboardOpenWnnPlugin PROPERTY IMPORTED_LOCATION_RELWITHDEBINFO "${_qt_imported_location}")
endif()
if(_qt_imported_implib)
    set_property(TARGET Qt6::QtVirtualKeyboardOpenWnnPlugin PROPERTY IMPORTED_IMPLIB_RELWITHDEBINFO "${_qt_imported_implib}")
endif()
if(_qt_imported_soname)
    set_property(TARGET Qt6::QtVirtualKeyboardOpenWnnPlugin PROPERTY IMPORTED_SONAME_RELWITHDEBINFO "${_qt_imported_soname}")
endif()

# Import target "Qt6::QtVirtualKeyboardOpenWnnPlugin" for configuration "MinSizeRel"
set_property(TARGET Qt6::QtVirtualKeyboardOpenWnnPlugin APPEND PROPERTY IMPORTED_CONFIGURATIONS MINSIZEREL)

if(_qt_imported_location)
    set_property(TARGET Qt6::QtVirtualKeyboardOpenWnnPlugin PROPERTY IMPORTED_LOCATION_MINSIZEREL "${_qt_imported_location}")
endif()
if(_qt_imported_implib)
    set_property(TARGET Qt6::QtVirtualKeyboardOpenWnnPlugin PROPERTY IMPORTED_IMPLIB_MINSIZEREL "${_qt_imported_implib}")
endif()
if(_qt_imported_soname)
    set_property(TARGET Qt6::QtVirtualKeyboardOpenWnnPlugin PROPERTY IMPORTED_SONAME_MINSIZEREL "${_qt_imported_soname}")
endif()

# Default configuration
if(_qt_imported_location_default)
    set_property(TARGET Qt6::QtVirtualKeyboardOpenWnnPlugin PROPERTY IMPORTED_LOCATION "${_qt_imported_location_default}")
endif()
if(_qt_imported_implib_default)
    set_property(TARGET Qt6::QtVirtualKeyboardOpenWnnPlugin PROPERTY IMPORTED_IMPLIB "${_qt_imported_implib_default}")
endif()
if(_qt_imported_soname_default)
    set_property(TARGET Qt6::QtVirtualKeyboardOpenWnnPlugin PROPERTY IMPORTED_SONAME "${_qt_imported_soname_default}")
endif()

unset(_qt_imported_location)
unset(_qt_imported_location_default)
unset(_qt_imported_soname)
unset(_qt_imported_soname_default)

==> qt6-virtualkeyboard-6.3.1-1-aarch64.pkg.tar.xz: usr/lib/cmake/Qt6VirtualKeyboard/Qt6QtVirtualKeyboardOpenWnnPluginAdditionalTargetInfo.cmake <==
# Additional target information for Qt6QtVirtualKeyboardOpenWnnPlugin
if(NOT DEFINED QT_DEFAULT_IMPORT_CONFIGURATION)
    set(QT_DEFAULT_IMPORT_CONFIGURATION RELWITHDEBINFO)
endif()
__qt_internal_promote_target_to_global_checked(Qt6::QtVirtualKeyboardOpenWnnPlugin)
get_target_property(_qt_imported_location Qt6::QtVirtualKeyboardOpenWnnPlugin IMPORTED_LOCATION_RELWITHDEBINFO)
get_target_property(_qt_imported_location_default Qt6::QtVirtualKeyboardOpenWnnPlugin IMPORTED_LOCATION_${QT_DEFAULT_IMPORT_CONFIGURATION})

# Import target "Qt6::QtVirtualKeyboardOpenWnnPlugin" for configuration "Release"
set_property(TARGET Qt6::QtVirtualKeyboardOpenWnnPlugin APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)

if(_qt_imported_location)
    set_property(TARGET Qt6::QtVirtualKeyboardOpenWnnPlugin PROPERTY IMPORTED_LOCATION_RELEASE "${_qt_imported_location}")
endif()

# Import target "Qt6::QtVirtualKeyboardOpenWnnPlugin" for configuration "MinSizeRel"
set_property(TARGET Qt6::QtVirtualKeyboardOpenWnnPlugin APPEND PROPERTY IMPORTED_CONFIGURATIONS MINSIZEREL)

if(_qt_imported_location)
    set_property(TARGET Qt6::QtVirtualKeyboardOpenWnnPlugin PROPERTY IMPORTED_LOCATION_MINSIZEREL "${_qt_imported_location}")
endif()

# Default configuration
if(_qt_imported_location_default)
    set_property(TARGET Qt6::QtVirtualKeyboardOpenWnnPlugin PROPERTY IMPORTED_LOCATION "${_qt_imported_location_default}")
endif()

unset(_qt_imported_location)
unset(_qt_imported_location_default)
unset(_qt_imported_soname)
unset(_qt_imported_soname_default)
unset(_qt_imported_configs)
